searchData={"items":[{"type":"module","title":"Humaans","doc":"A HTTP client for the Humaans API.\n\nThis library provides an interface to the Humaans API, allowing you to manage\npeople, companies, bank accounts, compensations, timesheet entries, and more.\nIt follows a modular design where the main `Humaans` module serves as the\nentry point for creating clients, while specific resource modules handle\noperations for each resource type.\n\n[Humaans API Documentation](https://docs.humaans.io/api/)","ref":"Humaans.html"},{"type":"module","title":"Architecture - Humaans","doc":"The library follows a layered architecture:\n- `Humaans` - Main module that creates configured client instances\n- Resource modules (`People`, `Companies`, etc.) - Handle operations specific to each resource type\n- HTTP client - Abstracts the HTTP communication details in a configurable manner","ref":"Humaans.html#module-architecture"},{"type":"module","title":"Configuration Options - Humaans","doc":"When creating a client with `Humaans.new/1`, you can configure:\n\n* `:access_token` - Your Humaans API access token (required)\n* `:base_url` - The base URL for API requests (defaults to \"https://app.humaans.io/api\")\n* `:http_client` - The HTTP client module to use (defaults to `Humaans.HTTPClient.Req`)","ref":"Humaans.html#module-configuration-options"},{"type":"module","title":"Examples - Humaans","doc":"# Create a default client\n    client = Humaans.new(access_token: \"some-access-token\")\n\n    # Create a client with custom base URL\n    client = Humaans.new(\n      access_token: \"some-access-token\",\n      base_url: \"https://custom-instance.humaans.io/api\"\n    )\n\n    # Create a client with custom HTTP client\n    client = Humaans.new(\n      access_token: \"some-access-token\",\n      http_client: MyCustomHTTPClient\n    )\n\n    # Make API calls\n    {:ok, people} = Humaans.People.list(client)\n    {:ok, person} = Humaans.People.retrieve(client, \"123\")\n    {:ok, companies} = Humaans.Companies.list(client)\n\n    # Create a new person\n    person_params = %{\n      \"firstName\" => \"Jane\",\n      \"lastName\" => \"Doe\",\n      \"email\" => \"jane.doe@example.com\"\n    }\n    {:ok, new_person} = Humaans.People.create(client, person_params)","ref":"Humaans.html#module-examples"},{"type":"function","title":"Humaans.bank_accounts/0","doc":"Access the Bank Accounts API.\n\nReturns the module that contains functions for working with bank account resources.","ref":"Humaans.html#bank_accounts/0"},{"type":"function","title":"Humaans.companies/0","doc":"Access the Companies API.\n\nReturns the module that contains functions for working with company resources.","ref":"Humaans.html#companies/0"},{"type":"function","title":"Humaans.compensation_types/0","doc":"Access the Compensation Types API.\n\nReturns the module that contains functions for working with compensation type resources.","ref":"Humaans.html#compensation_types/0"},{"type":"function","title":"Humaans.compensations/0","doc":"Access the Compensations API.\n\nReturns the module that contains functions for working with compensation resources.","ref":"Humaans.html#compensations/0"},{"type":"function","title":"Humaans.new/1","doc":"Creates a new client with the given access token and optional parameters.","ref":"Humaans.html#new/1"},{"type":"function","title":"Options - Humaans.new/1","doc":"* `:access_token` - The access token to use for authentication (required)\n  * `:base_url` - The base URL for API requests (defaults to https://app.humaans.io/api)","ref":"Humaans.html#new/1-options"},{"type":"function","title":"Examples - Humaans.new/1","doc":"iex> client = Humaans.new(access_token: \"some-access-token\")\n    iex> is_map(client)\n    true","ref":"Humaans.html#new/1-examples"},{"type":"function","title":"Humaans.people/0","doc":"Access the People API.\n\nReturns the module that contains functions for working with people resources.","ref":"Humaans.html#people/0"},{"type":"type","title":"Humaans.t/0","doc":"","ref":"Humaans.html#t:t/0"},{"type":"function","title":"Humaans.timesheet_entries/0","doc":"Access the Timesheet Entries API.\n\nReturns the module that contains functions for working with timesheet entry resources.","ref":"Humaans.html#timesheet_entries/0"},{"type":"function","title":"Humaans.timesheet_submissions/0","doc":"Access the Timesheet Submissions API.\n\nReturns the module that contains functions for working with timesheet submission resources.","ref":"Humaans.html#timesheet_submissions/0"},{"type":"behaviour","title":"Humaans.BankAccounts","doc":"This module provides functions for managing bank account resources in the\nHumaans API.","ref":"Humaans.BankAccounts.html"},{"type":"function","title":"Humaans.BankAccounts.create/2","doc":"Creates a new bank account resource.","ref":"Humaans.BankAccounts.html#create/2"},{"type":"function","title":"Parameters - Humaans.BankAccounts.create/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Map of parameters for the new bank account","ref":"Humaans.BankAccounts.html#create/2-parameters"},{"type":"function","title":"Examples - Humaans.BankAccounts.create/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{\n      personId: \"person_id\",\n      accountType: \"personal\",\n      accountHolder: \"Jane Doe\",\n      accountNumber: \"12345678\",\n      sortCode: \"01-02-03\"\n    }\n\n    {:ok, account} = Humaans.BankAccounts.create(client, params)","ref":"Humaans.BankAccounts.html#create/2-examples"},{"type":"callback","title":"Humaans.BankAccounts.create/2","doc":"","ref":"Humaans.BankAccounts.html#c:create/2"},{"type":"function","title":"Humaans.BankAccounts.delete/2","doc":"Deletes a specific bank account by ID.","ref":"Humaans.BankAccounts.html#delete/2"},{"type":"function","title":"Parameters - Humaans.BankAccounts.delete/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the bank account to delete","ref":"Humaans.BankAccounts.html#delete/2-parameters"},{"type":"function","title":"Examples - Humaans.BankAccounts.delete/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, result} = Humaans.BankAccounts.delete(client, \"account_id\")\n    # result contains %{id: \"account_id\", deleted: true}","ref":"Humaans.BankAccounts.html#delete/2-examples"},{"type":"callback","title":"Humaans.BankAccounts.delete/2","doc":"","ref":"Humaans.BankAccounts.html#c:delete/2"},{"type":"type","title":"Humaans.BankAccounts.delete_response/0","doc":"","ref":"Humaans.BankAccounts.html#t:delete_response/0"},{"type":"function","title":"Humaans.BankAccounts.list/2","doc":"Lists all bank account resources.\n\nReturns a list of bank account resources that match the optional filters provided in `params`.","ref":"Humaans.BankAccounts.html#list/2"},{"type":"function","title":"Parameters - Humaans.BankAccounts.list/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Optional parameters for filtering the results (default: `%{}`)","ref":"Humaans.BankAccounts.html#list/2-parameters"},{"type":"function","title":"Examples - Humaans.BankAccounts.list/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    # List all bank accounts\n    {:ok, accounts} = Humaans.BankAccounts.list(client)\n\n    # List with filtering parameters\n    {:ok, accounts} = Humaans.BankAccounts.list(client, %{limit: 10})","ref":"Humaans.BankAccounts.html#list/2-examples"},{"type":"callback","title":"Humaans.BankAccounts.list/2","doc":"","ref":"Humaans.BankAccounts.html#c:list/2"},{"type":"type","title":"Humaans.BankAccounts.list_response/0","doc":"","ref":"Humaans.BankAccounts.html#t:list_response/0"},{"type":"type","title":"Humaans.BankAccounts.response/0","doc":"","ref":"Humaans.BankAccounts.html#t:response/0"},{"type":"function","title":"Humaans.BankAccounts.retrieve/2","doc":"Retrieves a specific bank account by ID.","ref":"Humaans.BankAccounts.html#retrieve/2"},{"type":"function","title":"Parameters - Humaans.BankAccounts.retrieve/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the bank account to retrieve","ref":"Humaans.BankAccounts.html#retrieve/2-parameters"},{"type":"function","title":"Examples - Humaans.BankAccounts.retrieve/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, account} = Humaans.BankAccounts.retrieve(client, \"account_id\")","ref":"Humaans.BankAccounts.html#retrieve/2-examples"},{"type":"callback","title":"Humaans.BankAccounts.retrieve/2","doc":"","ref":"Humaans.BankAccounts.html#c:retrieve/2"},{"type":"function","title":"Humaans.BankAccounts.update/3","doc":"Updates a specific bank account by ID.","ref":"Humaans.BankAccounts.html#update/3"},{"type":"function","title":"Parameters - Humaans.BankAccounts.update/3","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the bank account to update\n  * `params` - Map of parameters to update","ref":"Humaans.BankAccounts.html#update/3-parameters"},{"type":"function","title":"Examples - Humaans.BankAccounts.update/3","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{accountHolder: \"Janet Doe\"}\n\n    {:ok, updated_account} = Humaans.BankAccounts.update(client, \"account_id\", params)","ref":"Humaans.BankAccounts.html#update/3-examples"},{"type":"callback","title":"Humaans.BankAccounts.update/3","doc":"","ref":"Humaans.BankAccounts.html#c:update/3"},{"type":"module","title":"Humaans.Client","doc":"Internal module for making HTTP requests to the Humaans API.\n\nThis module provides a consistent interface for all HTTP operations used by the\nresource modules. It handles:\n\n* Constructing proper URLs\n* Setting up appropriate headers\n* Selecting the right HTTP method\n* Processing request parameters\n* Delegating to the configured HTTP client","ref":"Humaans.Client.html"},{"type":"module","title":"Architecture - Humaans.Client","doc":"The client module sits between resource modules (like `Humaans.People`) and the\nactual HTTP client implementation (like `Humaans.HTTPClient.Req`):\n\n```\nResource Modules (People, Companies, etc.)\n       │\n       ▼\n  Humaans.Client\n       │\n       ▼\nHTTP Client Implementation\n```\n\nThis layered approach allows:\n1. Resource modules to focus on their specific API operations\n2. HTTP client implementations to focus on HTTP communication details\n3. This module to provide a consistent interface between them","ref":"Humaans.Client.html#module-architecture"},{"type":"module","title":"Internal Use - Humaans.Client","doc":"This module is primarily meant for internal use by other modules in the library.\nEnd users should interact with the resource modules instead.","ref":"Humaans.Client.html#module-internal-use"},{"type":"function","title":"Humaans.Client.delete/2","doc":"Makes a DELETE request to the specified path.\n\nUsed for deleting resources from the Humaans API.","ref":"Humaans.Client.html#delete/2"},{"type":"function","title":"Parameters - Humaans.Client.delete/2","doc":"* `client` - The Humaans client struct\n* `path` - API endpoint path (e.g., \"/people/123\")","ref":"Humaans.Client.html#delete/2-parameters"},{"type":"function","title":"Returns - Humaans.Client.delete/2","doc":"* `{:ok, response}` - Successful deletion response\n* `{:error, reason}` - Error response","ref":"Humaans.Client.html#delete/2-returns"},{"type":"function","title":"Humaans.Client.get/2","doc":"Makes a GET request to the specified path.\n\nUsed for retrieving resources from the Humaans API.","ref":"Humaans.Client.html#get/2"},{"type":"function","title":"Parameters - Humaans.Client.get/2","doc":"* `client` - The Humaans client struct\n* `path` - API endpoint path (e.g., \"/people/123\")","ref":"Humaans.Client.html#get/2-parameters"},{"type":"function","title":"Returns - Humaans.Client.get/2","doc":"* `{:ok, response}` - Successful response with retrieved data\n* `{:error, reason}` - Error response","ref":"Humaans.Client.html#get/2-returns"},{"type":"function","title":"Humaans.Client.get/3","doc":"Makes a GET request with query parameters.\n\nUsed for retrieving resources with filtering, pagination, or other query parameters.","ref":"Humaans.Client.html#get/3"},{"type":"function","title":"Parameters - Humaans.Client.get/3","doc":"* `client` - The Humaans client struct\n* `path` - API endpoint path (e.g., \"/people\")\n* `params` - Query parameters as keyword list (e.g., [limit: 10, skip: 20])","ref":"Humaans.Client.html#get/3-parameters"},{"type":"function","title":"Returns - Humaans.Client.get/3","doc":"* `{:ok, response}` - Successful response with retrieved data\n* `{:error, reason}` - Error response","ref":"Humaans.Client.html#get/3-returns"},{"type":"function","title":"Humaans.Client.patch/3","doc":"Makes a PATCH request to update an existing resource.\n\nUsed for updating resources in the Humaans API.","ref":"Humaans.Client.html#patch/3"},{"type":"function","title":"Parameters - Humaans.Client.patch/3","doc":"* `client` - The Humaans client struct\n* `path` - API endpoint path (e.g., \"/people/123\")\n* `params` - Request body parameters with fields to update (optional, defaults to empty list)","ref":"Humaans.Client.html#patch/3-parameters"},{"type":"function","title":"Returns - Humaans.Client.patch/3","doc":"* `{:ok, response}` - Successful response with updated resource data\n* `{:error, reason}` - Error response","ref":"Humaans.Client.html#patch/3-returns"},{"type":"function","title":"Humaans.Client.post/3","doc":"Makes a POST request to create a new resource.\n\nUsed for creating new resources in the Humaans API.","ref":"Humaans.Client.html#post/3"},{"type":"function","title":"Parameters - Humaans.Client.post/3","doc":"* `client` - The Humaans client struct\n* `path` - API endpoint path (e.g., \"/people\")\n* `params` - Request body parameters (optional, defaults to empty list)","ref":"Humaans.Client.html#post/3-parameters"},{"type":"function","title":"Returns - Humaans.Client.post/3","doc":"* `{:ok, response}` - Successful response with created resource data\n* `{:error, reason}` - Error response","ref":"Humaans.Client.html#post/3-returns"},{"type":"type","title":"Humaans.Client.response/0","doc":"Standard response format from HTTP operations.\n\n* `{:ok, map()}` - Successful response with decoded response body\n* `{:error, map()}` - Error response with error details","ref":"Humaans.Client.html#t:response/0"},{"type":"behaviour","title":"Humaans.Companies","doc":"This module provides functions for managing company resources in the Humaans\nAPI.  Note that unlike other resources, companies can only be listed,\nretrieved, and updated, but not created or deleted through the API.","ref":"Humaans.Companies.html"},{"type":"function","title":"Humaans.Companies.get/2","doc":"Retrieves a specific company by ID.","ref":"Humaans.Companies.html#get/2"},{"type":"function","title":"Parameters - Humaans.Companies.get/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the company to retrieve","ref":"Humaans.Companies.html#get/2-parameters"},{"type":"function","title":"Examples - Humaans.Companies.get/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, company} = Humaans.Companies.get(client, \"company_id\")","ref":"Humaans.Companies.html#get/2-examples"},{"type":"callback","title":"Humaans.Companies.get/2","doc":"","ref":"Humaans.Companies.html#c:get/2"},{"type":"function","title":"Humaans.Companies.list/2","doc":"Lists all company resources.\n\nReturns a list of company resources that match the optional filters provided in `params`.","ref":"Humaans.Companies.html#list/2"},{"type":"function","title":"Parameters - Humaans.Companies.list/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Optional parameters for filtering the results (default: `%{}`)","ref":"Humaans.Companies.html#list/2-parameters"},{"type":"function","title":"Examples - Humaans.Companies.list/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    # List all companies\n    {:ok, companies} = Humaans.Companies.list(client)\n\n    # List with filtering parameters\n    {:ok, companies} = Humaans.Companies.list(client, %{limit: 10})","ref":"Humaans.Companies.html#list/2-examples"},{"type":"callback","title":"Humaans.Companies.list/2","doc":"","ref":"Humaans.Companies.html#c:list/2"},{"type":"type","title":"Humaans.Companies.list_response/0","doc":"","ref":"Humaans.Companies.html#t:list_response/0"},{"type":"type","title":"Humaans.Companies.response/0","doc":"","ref":"Humaans.Companies.html#t:response/0"},{"type":"function","title":"Humaans.Companies.update/3","doc":"Updates a specific company by ID.","ref":"Humaans.Companies.html#update/3"},{"type":"function","title":"Parameters - Humaans.Companies.update/3","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the company to update\n  * `params` - Map of parameters to update","ref":"Humaans.Companies.html#update/3-parameters"},{"type":"function","title":"Examples - Humaans.Companies.update/3","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{name: \"New Company Name\"}\n\n    {:ok, updated_company} = Humaans.Companies.update(client, \"company_id\", params)","ref":"Humaans.Companies.html#update/3-examples"},{"type":"callback","title":"Humaans.Companies.update/3","doc":"","ref":"Humaans.Companies.html#c:update/3"},{"type":"behaviour","title":"Humaans.CompensationTypes","doc":"This module provides functions for managing compensation type resources in the\nHumaans API. Compensation types are used to define different categories of\ncompensation such as salary, bonus, commission, etc.","ref":"Humaans.CompensationTypes.html"},{"type":"function","title":"Humaans.CompensationTypes.create/2","doc":"Creates a new compensation type resource.","ref":"Humaans.CompensationTypes.html#create/2"},{"type":"function","title":"Parameters - Humaans.CompensationTypes.create/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Map of parameters for the new compensation type","ref":"Humaans.CompensationTypes.html#create/2-parameters"},{"type":"function","title":"Examples - Humaans.CompensationTypes.create/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{\n      name: \"Annual Bonus\",\n      category: \"bonus\",\n      payFrequency: \"once\",\n      recurring: true\n    }\n\n    {:ok, comp_type} = Humaans.CompensationTypes.create(client, params)","ref":"Humaans.CompensationTypes.html#create/2-examples"},{"type":"callback","title":"Humaans.CompensationTypes.create/2","doc":"","ref":"Humaans.CompensationTypes.html#c:create/2"},{"type":"function","title":"Humaans.CompensationTypes.delete/2","doc":"Deletes a specific compensation type by ID.","ref":"Humaans.CompensationTypes.html#delete/2"},{"type":"function","title":"Parameters - Humaans.CompensationTypes.delete/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the compensation type to delete","ref":"Humaans.CompensationTypes.html#delete/2-parameters"},{"type":"function","title":"Examples - Humaans.CompensationTypes.delete/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, result} = Humaans.CompensationTypes.delete(client, \"type_id\")\n    # result contains %{id: \"type_id\", deleted: true}","ref":"Humaans.CompensationTypes.html#delete/2-examples"},{"type":"callback","title":"Humaans.CompensationTypes.delete/2","doc":"","ref":"Humaans.CompensationTypes.html#c:delete/2"},{"type":"type","title":"Humaans.CompensationTypes.delete_response/0","doc":"","ref":"Humaans.CompensationTypes.html#t:delete_response/0"},{"type":"function","title":"Humaans.CompensationTypes.list/2","doc":"Lists all compensation type resources.\n\nReturns a list of compensation type resources that match the optional filters provided in `params`.","ref":"Humaans.CompensationTypes.html#list/2"},{"type":"function","title":"Parameters - Humaans.CompensationTypes.list/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Optional parameters for filtering the results (default: `%{}`)","ref":"Humaans.CompensationTypes.html#list/2-parameters"},{"type":"function","title":"Examples - Humaans.CompensationTypes.list/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    # List all compensation types\n    {:ok, types} = Humaans.CompensationTypes.list(client)\n\n    # List with filtering parameters\n    {:ok, types} = Humaans.CompensationTypes.list(client, %{limit: 10})","ref":"Humaans.CompensationTypes.html#list/2-examples"},{"type":"callback","title":"Humaans.CompensationTypes.list/2","doc":"","ref":"Humaans.CompensationTypes.html#c:list/2"},{"type":"type","title":"Humaans.CompensationTypes.list_response/0","doc":"","ref":"Humaans.CompensationTypes.html#t:list_response/0"},{"type":"type","title":"Humaans.CompensationTypes.response/0","doc":"","ref":"Humaans.CompensationTypes.html#t:response/0"},{"type":"function","title":"Humaans.CompensationTypes.retrieve/2","doc":"Retrieves a specific compensation type by ID.","ref":"Humaans.CompensationTypes.html#retrieve/2"},{"type":"function","title":"Parameters - Humaans.CompensationTypes.retrieve/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the compensation type to retrieve","ref":"Humaans.CompensationTypes.html#retrieve/2-parameters"},{"type":"function","title":"Examples - Humaans.CompensationTypes.retrieve/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, comp_type} = Humaans.CompensationTypes.retrieve(client, \"type_id\")","ref":"Humaans.CompensationTypes.html#retrieve/2-examples"},{"type":"callback","title":"Humaans.CompensationTypes.retrieve/2","doc":"","ref":"Humaans.CompensationTypes.html#c:retrieve/2"},{"type":"function","title":"Humaans.CompensationTypes.update/3","doc":"Updates a specific compensation type by ID.","ref":"Humaans.CompensationTypes.html#update/3"},{"type":"function","title":"Parameters - Humaans.CompensationTypes.update/3","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the compensation type to update\n  * `params` - Map of parameters to update","ref":"Humaans.CompensationTypes.html#update/3-parameters"},{"type":"function","title":"Examples - Humaans.CompensationTypes.update/3","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{name: \"Quarterly Bonus\", payFrequency: \"quarterly\"}\n\n    {:ok, updated_type} = Humaans.CompensationTypes.update(client, \"type_id\", params)","ref":"Humaans.CompensationTypes.html#update/3-examples"},{"type":"callback","title":"Humaans.CompensationTypes.update/3","doc":"","ref":"Humaans.CompensationTypes.html#c:update/3"},{"type":"behaviour","title":"Humaans.Compensations","doc":"This module provides functions for managing compensation resources in the\nHumaans API. Compensations represent the actual monetary values assigned to a\nperson under a specific compensation type (e.g., a specific person's salary or\nbonus).","ref":"Humaans.Compensations.html"},{"type":"function","title":"Humaans.Compensations.create/2","doc":"Creates a new compensation resource.","ref":"Humaans.Compensations.html#create/2"},{"type":"function","title":"Parameters - Humaans.Compensations.create/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Map of parameters for the new compensation","ref":"Humaans.Compensations.html#create/2-parameters"},{"type":"function","title":"Examples - Humaans.Compensations.create/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{\n      personId: \"person_id\",\n      compensationTypeId: \"comp_type_id\",\n      amount: \"70000\",\n      currency: \"EUR\",\n      period: \"annual\",\n      effectiveDate: \"2023-01-01\"\n    }\n\n    {:ok, compensation} = Humaans.Compensations.create(client, params)","ref":"Humaans.Compensations.html#create/2-examples"},{"type":"callback","title":"Humaans.Compensations.create/2","doc":"","ref":"Humaans.Compensations.html#c:create/2"},{"type":"function","title":"Humaans.Compensations.delete/2","doc":"Deletes a specific compensation by ID.","ref":"Humaans.Compensations.html#delete/2"},{"type":"function","title":"Parameters - Humaans.Compensations.delete/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the compensation to delete","ref":"Humaans.Compensations.html#delete/2-parameters"},{"type":"function","title":"Examples - Humaans.Compensations.delete/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, result} = Humaans.Compensations.delete(client, \"comp_id\")\n    # result contains %{id: \"comp_id\", deleted: true}","ref":"Humaans.Compensations.html#delete/2-examples"},{"type":"callback","title":"Humaans.Compensations.delete/2","doc":"","ref":"Humaans.Compensations.html#c:delete/2"},{"type":"type","title":"Humaans.Compensations.delete_response/0","doc":"","ref":"Humaans.Compensations.html#t:delete_response/0"},{"type":"function","title":"Humaans.Compensations.list/2","doc":"Lists all compensation resources.\n\nReturns a list of compensation resources that match the optional filters provided in `params`.","ref":"Humaans.Compensations.html#list/2"},{"type":"function","title":"Parameters - Humaans.Compensations.list/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Optional parameters for filtering the results (default: `%{}`)","ref":"Humaans.Compensations.html#list/2-parameters"},{"type":"function","title":"Examples - Humaans.Compensations.list/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    # List all compensations\n    {:ok, compensations} = Humaans.Compensations.list(client)\n\n    # List with filtering parameters\n    {:ok, compensations} = Humaans.Compensations.list(client, %{personId: \"person_id\"})","ref":"Humaans.Compensations.html#list/2-examples"},{"type":"callback","title":"Humaans.Compensations.list/2","doc":"","ref":"Humaans.Compensations.html#c:list/2"},{"type":"type","title":"Humaans.Compensations.list_response/0","doc":"","ref":"Humaans.Compensations.html#t:list_response/0"},{"type":"type","title":"Humaans.Compensations.response/0","doc":"","ref":"Humaans.Compensations.html#t:response/0"},{"type":"function","title":"Humaans.Compensations.retrieve/2","doc":"Retrieves a specific compensation by ID.","ref":"Humaans.Compensations.html#retrieve/2"},{"type":"function","title":"Parameters - Humaans.Compensations.retrieve/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the compensation to retrieve","ref":"Humaans.Compensations.html#retrieve/2-parameters"},{"type":"function","title":"Examples - Humaans.Compensations.retrieve/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, compensation} = Humaans.Compensations.retrieve(client, \"comp_id\")","ref":"Humaans.Compensations.html#retrieve/2-examples"},{"type":"callback","title":"Humaans.Compensations.retrieve/2","doc":"","ref":"Humaans.Compensations.html#c:retrieve/2"},{"type":"function","title":"Humaans.Compensations.update/3","doc":"Updates a specific compensation by ID.","ref":"Humaans.Compensations.html#update/3"},{"type":"function","title":"Parameters - Humaans.Compensations.update/3","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the compensation to update\n  * `params` - Map of parameters to update","ref":"Humaans.Compensations.html#update/3-parameters"},{"type":"function","title":"Examples - Humaans.Compensations.update/3","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{amount: \"75000\", note: \"Annual raise\"}\n\n    {:ok, updated_comp} = Humaans.Compensations.update(client, \"comp_id\", params)","ref":"Humaans.Compensations.html#update/3-examples"},{"type":"callback","title":"Humaans.Compensations.update/3","doc":"","ref":"Humaans.Compensations.html#c:update/3"},{"type":"behaviour","title":"Humaans.HTTPClient.Behaviour","doc":"Behaviour for Humaans HTTP clients.\n\nThis module defines the interface that all HTTP client implementations must follow.\nThe library comes with a default implementation using the Req HTTP client\n(`Humaans.HTTPClient.Req`), but you can provide your own implementation by:\n\n1. Creating a module that implements this behaviour\n2. Passing your module to `Humaans.new/1` as the `:http_client` option","ref":"Humaans.HTTPClient.Behaviour.html"},{"type":"behaviour","title":"Custom Client Implementation - Humaans.HTTPClient.Behaviour","doc":"A custom HTTP client must implement the `request/2` callback, which handles\nall HTTP communication with the Humaans API. Your implementation should:\n\n- Apply proper authentication using the client's access token\n- Handle request and response encoding/decoding\n- Process errors appropriately\n- Return standardized response structures\n\nExample of a minimal custom implementation:\n\n    defmodule MyCustomHTTPClient do\n      @behaviour Humaans.HTTPClient.Behaviour\n\n      @impl true\n      def request(client, opts) do\n        # Implement the HTTP request logic\n        # Return {:ok, response} or {:error, reason}\n      end\n    end\n\n    # Then use it with:\n    client = Humaans.new(\n      access_token: \"token\",\n      http_client: MyCustomHTTPClient\n    )","ref":"Humaans.HTTPClient.Behaviour.html#module-custom-client-implementation"},{"type":"callback","title":"Humaans.HTTPClient.Behaviour.request/2","doc":"Makes an HTTP request to the Humaans API.","ref":"Humaans.HTTPClient.Behaviour.html#c:request/2"},{"type":"callback","title":"Parameters - Humaans.HTTPClient.Behaviour.request/2","doc":"- `client` - A Humaans client struct containing configuration\n- `opts` - Request options including:\n  - `:method` - HTTP method (`:get`, `:post`, `:patch`, `:delete`, etc.)\n  - `:url` - The path to request, which will be appended to the base URL\n  - `:headers` - HTTP headers to include in the request\n  - `:body` - Request body for POST/PATCH requests (optional)\n  - `:params` - Query parameters for GET requests (optional)","ref":"Humaans.HTTPClient.Behaviour.html#c:request/2-parameters"},{"type":"callback","title":"Returns - Humaans.HTTPClient.Behaviour.request/2","doc":"- `{:ok, response}` - Successful response with parsed body\n- `{:error, reason}` - Error with reason","ref":"Humaans.HTTPClient.Behaviour.html#c:request/2-returns"},{"type":"module","title":"Humaans.HTTPClient.Req","doc":"Default HTTP client implementation using `Req`.\n\nThis module is used by default when you create a new Humaans client without\nspecifying a custom HTTP client.","ref":"Humaans.HTTPClient.Req.html"},{"type":"module","title":"Customization - Humaans.HTTPClient.Req","doc":"If you need to customize the Req client behavior (such as adding middleware,\nchanging timeouts, etc.), you can implement your own client module that builds\non this implementation while adding your specific modifications.\n\n```elixir\ndefmodule MyCustomReqClient do\n  @behaviour Humaans.HTTPClient.Behaviour\n\n  @impl true\n  def request(client, opts) do\n    Req.new(\n      base_url: client.base_url,\n      auth: {:bearer, client.access_token},\n      connect_options: [timeout: 30_000] # Custom timeout\n    )\n    |> Req.merge(opts)\n    # Add custom Req plugins or middleware here\n    |> Req.request()\n  end\nend\n```","ref":"Humaans.HTTPClient.Req.html#module-customization"},{"type":"function","title":"Humaans.HTTPClient.Req.request/2","doc":"Makes an HTTP request to the Humaans API using `Req`.","ref":"Humaans.HTTPClient.Req.html#request/2"},{"type":"function","title":"Parameters - Humaans.HTTPClient.Req.request/2","doc":"- `client` - `Humaans` struct containing configuration\n- `opts` - Request options to be merged with the Req client","ref":"Humaans.HTTPClient.Req.html#request/2-parameters"},{"type":"function","title":"Returns - Humaans.HTTPClient.Req.request/2","doc":"- `{:ok, response}` - Successful response with parsed body\n- `{:error, reason}` - Error with reason","ref":"Humaans.HTTPClient.Req.html#request/2-returns"},{"type":"behaviour","title":"Humaans.People","doc":"This module provides functions for managing people resources in the Humaans\nAPI.","ref":"Humaans.People.html"},{"type":"function","title":"Humaans.People.create/2","doc":"Creates a new person resource.","ref":"Humaans.People.html#create/2"},{"type":"function","title":"Parameters - Humaans.People.create/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Map of parameters for the new person","ref":"Humaans.People.html#create/2-parameters"},{"type":"function","title":"Examples - Humaans.People.create/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{\n      firstName: \"Jane\",\n      lastName: \"Doe\",\n      email: \"jane@example.com\"\n    }\n\n    {:ok, person} = Humaans.People.create(client, params)","ref":"Humaans.People.html#create/2-examples"},{"type":"callback","title":"Humaans.People.create/2","doc":"","ref":"Humaans.People.html#c:create/2"},{"type":"function","title":"Humaans.People.delete/2","doc":"Deletes a specific person by ID.","ref":"Humaans.People.html#delete/2"},{"type":"function","title":"Parameters - Humaans.People.delete/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the person to delete","ref":"Humaans.People.html#delete/2-parameters"},{"type":"function","title":"Examples - Humaans.People.delete/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, result} = Humaans.People.delete(client, \"person_id\")\n    # result contains %{id: \"person_id\", deleted: true}","ref":"Humaans.People.html#delete/2-examples"},{"type":"callback","title":"Humaans.People.delete/2","doc":"","ref":"Humaans.People.html#c:delete/2"},{"type":"type","title":"Humaans.People.delete_response/0","doc":"","ref":"Humaans.People.html#t:delete_response/0"},{"type":"function","title":"Humaans.People.list/2","doc":"Lists all people resources.\n\nReturns a list of people resources that match the optional filters provided in `params`.","ref":"Humaans.People.html#list/2"},{"type":"function","title":"Parameters - Humaans.People.list/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Optional parameters for filtering the results (default: `%{}`)","ref":"Humaans.People.html#list/2-parameters"},{"type":"function","title":"Examples - Humaans.People.list/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    # List all people\n    {:ok, people} = Humaans.People.list(client)\n\n    # List with filtering parameters\n    {:ok, people} = Humaans.People.list(client, %{limit: 10})","ref":"Humaans.People.html#list/2-examples"},{"type":"callback","title":"Humaans.People.list/2","doc":"","ref":"Humaans.People.html#c:list/2"},{"type":"type","title":"Humaans.People.list_response/0","doc":"","ref":"Humaans.People.html#t:list_response/0"},{"type":"type","title":"Humaans.People.response/0","doc":"","ref":"Humaans.People.html#t:response/0"},{"type":"function","title":"Humaans.People.retrieve/2","doc":"Retrieves a specific person by ID.","ref":"Humaans.People.html#retrieve/2"},{"type":"function","title":"Parameters - Humaans.People.retrieve/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the person to retrieve","ref":"Humaans.People.html#retrieve/2-parameters"},{"type":"function","title":"Examples - Humaans.People.retrieve/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, person} = Humaans.People.retrieve(client, \"person_id\")","ref":"Humaans.People.html#retrieve/2-examples"},{"type":"callback","title":"Humaans.People.retrieve/2","doc":"","ref":"Humaans.People.html#c:retrieve/2"},{"type":"function","title":"Humaans.People.update/3","doc":"Updates a specific person by ID.","ref":"Humaans.People.html#update/3"},{"type":"function","title":"Parameters - Humaans.People.update/3","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the person to update\n  * `params` - Map of parameters to update","ref":"Humaans.People.html#update/3-parameters"},{"type":"function","title":"Examples - Humaans.People.update/3","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{firstName: \"Janet\"}\n\n    {:ok, updated_person} = Humaans.People.update(client, \"person_id\", params)","ref":"Humaans.People.html#update/3-examples"},{"type":"callback","title":"Humaans.People.update/3","doc":"","ref":"Humaans.People.html#c:update/3"},{"type":"module","title":"Humaans.Resources.BankAccount","doc":"Representation of a Bank Account resource.","ref":"Humaans.Resources.BankAccount.html"},{"type":"function","title":"Humaans.Resources.BankAccount.new/2","doc":"","ref":"Humaans.Resources.BankAccount.html#new/2"},{"type":"type","title":"Humaans.Resources.BankAccount.t/0","doc":"","ref":"Humaans.Resources.BankAccount.html#t:t/0"},{"type":"module","title":"Humaans.Resources.Company","doc":"Representation of a Company resource.","ref":"Humaans.Resources.Company.html"},{"type":"function","title":"Humaans.Resources.Company.new/2","doc":"","ref":"Humaans.Resources.Company.html#new/2"},{"type":"type","title":"Humaans.Resources.Company.payment_status/0","doc":"","ref":"Humaans.Resources.Company.html#t:payment_status/0"},{"type":"type","title":"Humaans.Resources.Company.status/0","doc":"","ref":"Humaans.Resources.Company.html#t:status/0"},{"type":"type","title":"Humaans.Resources.Company.t/0","doc":"","ref":"Humaans.Resources.Company.html#t:t/0"},{"type":"module","title":"Humaans.Resources.Compensation","doc":"Representation of a Compensation resource.","ref":"Humaans.Resources.Compensation.html"},{"type":"type","title":"Humaans.Resources.Compensation.base_type/0","doc":"","ref":"Humaans.Resources.Compensation.html#t:base_type/0"},{"type":"function","title":"Humaans.Resources.Compensation.new/2","doc":"","ref":"Humaans.Resources.Compensation.html#new/2"},{"type":"type","title":"Humaans.Resources.Compensation.t/0","doc":"","ref":"Humaans.Resources.Compensation.html#t:t/0"},{"type":"module","title":"Humaans.Resources.CompensationType","doc":"Representation of a Compensation Type resource.","ref":"Humaans.Resources.CompensationType.html"},{"type":"type","title":"Humaans.Resources.CompensationType.base_type/0","doc":"","ref":"Humaans.Resources.CompensationType.html#t:base_type/0"},{"type":"function","title":"Humaans.Resources.CompensationType.new/2","doc":"","ref":"Humaans.Resources.CompensationType.html#new/2"},{"type":"type","title":"Humaans.Resources.CompensationType.t/0","doc":"","ref":"Humaans.Resources.CompensationType.html#t:t/0"},{"type":"module","title":"Humaans.Resources.Person","doc":"Representation of a Person resource.","ref":"Humaans.Resources.Person.html"},{"type":"function","title":"Humaans.Resources.Person.new/2","doc":"","ref":"Humaans.Resources.Person.html#new/2"},{"type":"type","title":"Humaans.Resources.Person.t/0","doc":"","ref":"Humaans.Resources.Person.html#t:t/0"},{"type":"module","title":"Humaans.Resources.TimesheetEntry","doc":"Representation of a Timesheet Entry resource.","ref":"Humaans.Resources.TimesheetEntry.html"},{"type":"function","title":"Humaans.Resources.TimesheetEntry.new/2","doc":"","ref":"Humaans.Resources.TimesheetEntry.html#new/2"},{"type":"type","title":"Humaans.Resources.TimesheetEntry.t/0","doc":"","ref":"Humaans.Resources.TimesheetEntry.html#t:t/0"},{"type":"module","title":"Humaans.Resources.TimesheetSubmission","doc":"Representation of a Timesheet Submission resource.","ref":"Humaans.Resources.TimesheetSubmission.html"},{"type":"function","title":"Humaans.Resources.TimesheetSubmission.new/2","doc":"","ref":"Humaans.Resources.TimesheetSubmission.html#new/2"},{"type":"type","title":"Humaans.Resources.TimesheetSubmission.t/0","doc":"","ref":"Humaans.Resources.TimesheetSubmission.html#t:t/0"},{"type":"module","title":"Humaans.ResponseHandler","doc":"This module provides helper functions for handling API responses consistently\nacross all Humaans API resource modules.","ref":"Humaans.ResponseHandler.html"},{"type":"function","title":"Humaans.ResponseHandler.handle_delete_response/1","doc":"Handles responses for delete operations, returning a map with deleted status and ID.","ref":"Humaans.ResponseHandler.html#handle_delete_response/1"},{"type":"function","title":"Parameters - Humaans.ResponseHandler.handle_delete_response/1","doc":"* `response` - The response tuple from the HTTP client","ref":"Humaans.ResponseHandler.html#handle_delete_response/1-parameters"},{"type":"function","title":"Examples - Humaans.ResponseHandler.handle_delete_response/1","doc":"response = Client.delete(client, \"/endpoint/id\")\n    ResponseHandler.handle_delete_response(response)","ref":"Humaans.ResponseHandler.html#handle_delete_response/1-examples"},{"type":"function","title":"Humaans.ResponseHandler.handle_list_response/2","doc":"Handles responses for list operations, converting raw API response data into a list of resource structs.","ref":"Humaans.ResponseHandler.html#handle_list_response/2"},{"type":"function","title":"Parameters - Humaans.ResponseHandler.handle_list_response/2","doc":"* `response` - The response tuple from the HTTP client\n  * `resource_module` - The module to use for converting the raw data to structs","ref":"Humaans.ResponseHandler.html#handle_list_response/2-parameters"},{"type":"function","title":"Examples - Humaans.ResponseHandler.handle_list_response/2","doc":"response = Client.get(client, \"/endpoint\", params)\n    ResponseHandler.handle_list_response(response, Resources.Person)","ref":"Humaans.ResponseHandler.html#handle_list_response/2-examples"},{"type":"function","title":"Humaans.ResponseHandler.handle_resource_response/2","doc":"Handles responses for single resource operations, converting raw API response data into a resource struct.","ref":"Humaans.ResponseHandler.html#handle_resource_response/2"},{"type":"function","title":"Parameters - Humaans.ResponseHandler.handle_resource_response/2","doc":"* `response` - The response tuple from the HTTP client\n  * `resource_module` - The module to use for converting the raw data to a struct","ref":"Humaans.ResponseHandler.html#handle_resource_response/2-parameters"},{"type":"function","title":"Examples - Humaans.ResponseHandler.handle_resource_response/2","doc":"response = Client.get(client, \"/endpoint/id\")\n    ResponseHandler.handle_resource_response(response, Resources.Person)","ref":"Humaans.ResponseHandler.html#handle_resource_response/2-examples"},{"type":"function","title":"Humaans.ResponseHandler.handle_response/2","doc":"Generic response handler for all API operations.","ref":"Humaans.ResponseHandler.html#handle_response/2"},{"type":"function","title":"Parameters - Humaans.ResponseHandler.handle_response/2","doc":"* `response` - The response tuple from the HTTP client\n  * `success_handler` - A function to process successful response bodies","ref":"Humaans.ResponseHandler.html#handle_response/2-parameters"},{"type":"behaviour","title":"Humaans.TimesheetEntries","doc":"This module provides functions for managing timesheet entry resources in the\nHumaans API. Timesheet entries represent individual time records for a person,\nsuch as hours worked on a specific date.","ref":"Humaans.TimesheetEntries.html"},{"type":"function","title":"Humaans.TimesheetEntries.create/2","doc":"Creates a new timesheet entry resource.","ref":"Humaans.TimesheetEntries.html#create/2"},{"type":"function","title":"Parameters - Humaans.TimesheetEntries.create/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Map of parameters for the new timesheet entry","ref":"Humaans.TimesheetEntries.html#create/2-parameters"},{"type":"function","title":"Examples - Humaans.TimesheetEntries.create/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{\n      personId: \"person_id\",\n      date: \"2023-01-10\",\n      startTime: \"09:00:00\",\n      endTime: \"17:00:00\"\n    }\n\n    {:ok, entry} = Humaans.TimesheetEntries.create(client, params)","ref":"Humaans.TimesheetEntries.html#create/2-examples"},{"type":"callback","title":"Humaans.TimesheetEntries.create/2","doc":"","ref":"Humaans.TimesheetEntries.html#c:create/2"},{"type":"function","title":"Humaans.TimesheetEntries.delete/2","doc":"Deletes a specific timesheet entry by ID.","ref":"Humaans.TimesheetEntries.html#delete/2"},{"type":"function","title":"Parameters - Humaans.TimesheetEntries.delete/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the timesheet entry to delete","ref":"Humaans.TimesheetEntries.html#delete/2-parameters"},{"type":"function","title":"Examples - Humaans.TimesheetEntries.delete/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, result} = Humaans.TimesheetEntries.delete(client, \"entry_id\")\n    # result contains %{id: \"entry_id\", deleted: true}","ref":"Humaans.TimesheetEntries.html#delete/2-examples"},{"type":"callback","title":"Humaans.TimesheetEntries.delete/2","doc":"","ref":"Humaans.TimesheetEntries.html#c:delete/2"},{"type":"type","title":"Humaans.TimesheetEntries.delete_response/0","doc":"","ref":"Humaans.TimesheetEntries.html#t:delete_response/0"},{"type":"function","title":"Humaans.TimesheetEntries.list/2","doc":"Lists all timesheet entry resources.\n\nReturns a list of timesheet entry resources that match the optional filters provided in `params`.","ref":"Humaans.TimesheetEntries.html#list/2"},{"type":"function","title":"Parameters - Humaans.TimesheetEntries.list/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Optional parameters for filtering the results (default: `%{}`)","ref":"Humaans.TimesheetEntries.html#list/2-parameters"},{"type":"function","title":"Examples - Humaans.TimesheetEntries.list/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    # List all timesheet entries\n    {:ok, entries} = Humaans.TimesheetEntries.list(client)\n\n    # List with filtering parameters\n    {:ok, entries} = Humaans.TimesheetEntries.list(client, %{personId: \"person_id\"})","ref":"Humaans.TimesheetEntries.html#list/2-examples"},{"type":"callback","title":"Humaans.TimesheetEntries.list/2","doc":"","ref":"Humaans.TimesheetEntries.html#c:list/2"},{"type":"type","title":"Humaans.TimesheetEntries.list_response/0","doc":"","ref":"Humaans.TimesheetEntries.html#t:list_response/0"},{"type":"type","title":"Humaans.TimesheetEntries.response/0","doc":"","ref":"Humaans.TimesheetEntries.html#t:response/0"},{"type":"function","title":"Humaans.TimesheetEntries.retrieve/2","doc":"Retrieves a specific timesheet entry by ID.","ref":"Humaans.TimesheetEntries.html#retrieve/2"},{"type":"function","title":"Parameters - Humaans.TimesheetEntries.retrieve/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the timesheet entry to retrieve","ref":"Humaans.TimesheetEntries.html#retrieve/2-parameters"},{"type":"function","title":"Examples - Humaans.TimesheetEntries.retrieve/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, entry} = Humaans.TimesheetEntries.retrieve(client, \"entry_id\")","ref":"Humaans.TimesheetEntries.html#retrieve/2-examples"},{"type":"callback","title":"Humaans.TimesheetEntries.retrieve/2","doc":"","ref":"Humaans.TimesheetEntries.html#c:retrieve/2"},{"type":"function","title":"Humaans.TimesheetEntries.update/3","doc":"Updates a specific timesheet entry by ID.","ref":"Humaans.TimesheetEntries.html#update/3"},{"type":"function","title":"Parameters - Humaans.TimesheetEntries.update/3","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the timesheet entry to update\n  * `params` - Map of parameters to update","ref":"Humaans.TimesheetEntries.html#update/3-parameters"},{"type":"function","title":"Examples - Humaans.TimesheetEntries.update/3","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{startTime: \"10:00:00\", endTime: \"18:00:00\"}\n\n    {:ok, updated_entry} = Humaans.TimesheetEntries.update(client, \"entry_id\", params)","ref":"Humaans.TimesheetEntries.html#update/3-examples"},{"type":"callback","title":"Humaans.TimesheetEntries.update/3","doc":"","ref":"Humaans.TimesheetEntries.html#c:update/3"},{"type":"behaviour","title":"Humaans.TimesheetSubmissions","doc":"This module provides functions for managing timesheet submission resources in\nthe Humaans API. Timesheet submissions represent a collection of timesheet\nentries for a specific time period that has been submitted for review and\napproval.","ref":"Humaans.TimesheetSubmissions.html"},{"type":"function","title":"Humaans.TimesheetSubmissions.create/2","doc":"Creates a new timesheet submission resource.","ref":"Humaans.TimesheetSubmissions.html#create/2"},{"type":"function","title":"Parameters - Humaans.TimesheetSubmissions.create/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Map of parameters for the new timesheet submission","ref":"Humaans.TimesheetSubmissions.html#create/2-parameters"},{"type":"function","title":"Examples - Humaans.TimesheetSubmissions.create/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{\n      personId: \"person_id\",\n      startDate: \"2023-01-01\",\n      endDate: \"2023-01-31\",\n      status: \"pending\"\n    }\n\n    {:ok, submission} = Humaans.TimesheetSubmissions.create(client, params)","ref":"Humaans.TimesheetSubmissions.html#create/2-examples"},{"type":"callback","title":"Humaans.TimesheetSubmissions.create/2","doc":"","ref":"Humaans.TimesheetSubmissions.html#c:create/2"},{"type":"function","title":"Humaans.TimesheetSubmissions.delete/2","doc":"Deletes a specific timesheet submission by ID.","ref":"Humaans.TimesheetSubmissions.html#delete/2"},{"type":"function","title":"Parameters - Humaans.TimesheetSubmissions.delete/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the timesheet submission to delete","ref":"Humaans.TimesheetSubmissions.html#delete/2-parameters"},{"type":"function","title":"Examples - Humaans.TimesheetSubmissions.delete/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, result} = Humaans.TimesheetSubmissions.delete(client, \"submission_id\")\n    # result contains %{id: \"submission_id\", deleted: true}","ref":"Humaans.TimesheetSubmissions.html#delete/2-examples"},{"type":"callback","title":"Humaans.TimesheetSubmissions.delete/2","doc":"","ref":"Humaans.TimesheetSubmissions.html#c:delete/2"},{"type":"type","title":"Humaans.TimesheetSubmissions.delete_response/0","doc":"","ref":"Humaans.TimesheetSubmissions.html#t:delete_response/0"},{"type":"function","title":"Humaans.TimesheetSubmissions.list/2","doc":"Lists all timesheet submission resources.\n\nReturns a list of timesheet submission resources that match the optional filters provided in `params`.","ref":"Humaans.TimesheetSubmissions.html#list/2"},{"type":"function","title":"Parameters - Humaans.TimesheetSubmissions.list/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `params` - Optional parameters for filtering the results (default: `%{}`)","ref":"Humaans.TimesheetSubmissions.html#list/2-parameters"},{"type":"function","title":"Examples - Humaans.TimesheetSubmissions.list/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    # List all timesheet submissions\n    {:ok, submissions} = Humaans.TimesheetSubmissions.list(client)\n\n    # List with filtering parameters\n    {:ok, submissions} = Humaans.TimesheetSubmissions.list(client, %{personId: \"person_id\"})","ref":"Humaans.TimesheetSubmissions.html#list/2-examples"},{"type":"callback","title":"Humaans.TimesheetSubmissions.list/2","doc":"","ref":"Humaans.TimesheetSubmissions.html#c:list/2"},{"type":"type","title":"Humaans.TimesheetSubmissions.list_response/0","doc":"","ref":"Humaans.TimesheetSubmissions.html#t:list_response/0"},{"type":"type","title":"Humaans.TimesheetSubmissions.response/0","doc":"","ref":"Humaans.TimesheetSubmissions.html#t:response/0"},{"type":"function","title":"Humaans.TimesheetSubmissions.retrieve/2","doc":"Retrieves a specific timesheet submission by ID.","ref":"Humaans.TimesheetSubmissions.html#retrieve/2"},{"type":"function","title":"Parameters - Humaans.TimesheetSubmissions.retrieve/2","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the timesheet submission to retrieve","ref":"Humaans.TimesheetSubmissions.html#retrieve/2-parameters"},{"type":"function","title":"Examples - Humaans.TimesheetSubmissions.retrieve/2","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    {:ok, submission} = Humaans.TimesheetSubmissions.retrieve(client, \"submission_id\")","ref":"Humaans.TimesheetSubmissions.html#retrieve/2-examples"},{"type":"callback","title":"Humaans.TimesheetSubmissions.retrieve/2","doc":"","ref":"Humaans.TimesheetSubmissions.html#c:retrieve/2"},{"type":"function","title":"Humaans.TimesheetSubmissions.update/3","doc":"Updates a specific timesheet submission by ID.","ref":"Humaans.TimesheetSubmissions.html#update/3"},{"type":"function","title":"Parameters - Humaans.TimesheetSubmissions.update/3","doc":"* `client` - Client map created with `Humaans.new/1`\n  * `id` - String ID of the timesheet submission to update\n  * `params` - Map of parameters to update","ref":"Humaans.TimesheetSubmissions.html#update/3-parameters"},{"type":"function","title":"Examples - Humaans.TimesheetSubmissions.update/3","doc":"client = Humaans.new(access_token: \"your_access_token\")\n\n    params = %{status: \"approved\"}\n\n    {:ok, updated_submission} = Humaans.TimesheetSubmissions.update(client, \"submission_id\", params)","ref":"Humaans.TimesheetSubmissions.html#update/3-examples"},{"type":"callback","title":"Humaans.TimesheetSubmissions.update/3","doc":"","ref":"Humaans.TimesheetSubmissions.html#c:update/3"},{"type":"extras","title":"Humaans","doc":"# Humaans\n\n[![Hex Version](https://img.shields.io/hexpm/v/humaans.svg)](https://hex.pm/packages/humaans) [![Hex Docs](https://img.shields.io/badge/docs-hexpm-blue.svg)](https://hexdocs.pm/humaans/)\n\nAn Elixir client for the [Humaans API][humaans-api-docs].","ref":"readme.html"},{"type":"extras","title":"Installation - Humaans","doc":"The package can be installed by adding `humaans` to your list of dependencies in\n`mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:humaans, \"~> 0.4\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Humaans","doc":"To use this client with the Humaans API, you'll need to generate an API access token in the Humaans application.","ref":"readme.html#usage"},{"type":"extras","title":"Client-based approach - Humaans","doc":"The recommended way to use this library is to instantiate a client first:\n\n```elixir\n# Create a client with your access token\nclient = Humaans.new(access_token: \"YOUR_ACCESS_TOKEN\")\n\n# Make API requests passing the client as the first argument\n{:ok, people} = Humaans.People.list(client)\n{:ok, person} = Humaans.People.retrieve(client, \"person_id\")\n{:ok, company} = Humaans.Companies.retrieve(client, \"company_id\")\n```\n\nThis approach allows you to create multiple clients with different access tokens and use them independently.","ref":"readme.html#client-based-approach"},{"type":"extras","title":"Module access helpers - Humaans","doc":"The library provides convenience functions to access the different resource modules:\n\n```elixir\nclient = Humaans.new(access_token: \"YOUR_ACCESS_TOKEN\")\n\n# Use the module access helpers\n{:ok, people} = Humaans.people().list(client)\n{:ok, accounts} = Humaans.bank_accounts().list(client)\n{:ok, companies} = Humaans.companies().list(client)\n```","ref":"readme.html#module-access-helpers"},{"type":"extras","title":"Available resources - Humaans","doc":"- `Humaans.People` - Work with people resources\n- `Humaans.BankAccounts` - Work with bank account resources\n- `Humaans.Companies` - Work with company resources\n- `Humaans.CompensationTypes` - Work with compensation type resources\n- `Humaans.Compensations` - Work with compensation resources\n- `Humaans.TimesheetEntries` - Work with timesheet entry resources\n- `Humaans.TimesheetSubmissions` - Work with timesheet submission resources","ref":"readme.html#available-resources"},{"type":"extras","title":"License - Humaans","doc":"Humaans is [released under the MIT license](LICENSE).\n\n[humaans-api-docs]: https://docs.humaans.io/api/","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file. See [Keep a\nCHANGELOG](http://keepachangelog.com/) for how to update this file. This project\nadheres to [Semantic Versioning](http://semver.org/).\n\n<!-- %% CHANGELOG_ENTRIES %% -->","ref":"changelog.html"},{"type":"extras","title":"0.4.1 - 2025-04-25 - Changelog","doc":"","ref":"changelog.html#0-4-1-2025-04-25"},{"type":"extras","title":"Changes - Changelog","doc":"-Fixed incorrect encoding of request body for HTTP patch, post and put methods.","ref":"changelog.html#changes"},{"type":"extras","title":"0.4.0 - 2025-03-11 - Changelog","doc":"","ref":"changelog.html#0-4-0-2025-03-11"},{"type":"extras","title":"Changed - Changelog","doc":"- Configurable HTTP client module\n- Updated and improved package and module documentation","ref":"changelog.html#changed"},{"type":"extras","title":"0.3.1 - 2025-03-04 - Changelog","doc":"","ref":"changelog.html#0-3-1-2025-03-04"},{"type":"extras","title":"Changed - Changelog","doc":"- Fixed existing release notes\n- Updated package release workflow","ref":"changelog.html#changed"},{"type":"extras","title":"0.3.0 - 2025-03-04 - Changelog","doc":"","ref":"changelog.html#0-3-0-2025-03-04"},{"type":"extras","title":"Changes - Changelog","doc":"- Introduce `ResponseHandler` to centrally manage how API responses are handled.","ref":"changelog.html#changes"},{"type":"extras","title":"0.2.2 - 2025-03-04 - Changelog","doc":"","ref":"changelog.html#0-2-2-2025-03-04"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Improved ExDoc configuration for HexDocs\n- Added changelog to package metadata for Hex.pm","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.2.1 - 2025-03-04 - Changelog","doc":"","ref":"changelog.html#0-2-1-2025-03-04"},{"type":"extras","title":"Changed - Changelog","doc":"- Provide default implementation for Humaans.Client.","ref":"changelog.html#changed"},{"type":"extras","title":"0.2.0 - 2025-03-03 - Changelog","doc":"","ref":"changelog.html#0-2-0-2025-03-03"},{"type":"extras","title":"Changed - Changelog","doc":"- **Breaking change**: Switched to a client-based approach instead of global configuration\n- Added convenience accessor functions for resource modules","ref":"changelog.html#changed"},{"type":"extras","title":"Usage changes - Changelog","doc":"Instead of using global configuration:\n```elixir\n{:ok, people} = Humaans.People.list()\n```\n\nNow use the client-based approach:\n```elixir\nclient = Humaans.new(access_token: \"YOUR_ACCESS_TOKEN\")\n{:ok, people} = Humaans.People.list(client)\n```","ref":"changelog.html#usage-changes"},{"type":"extras","title":"0.1.0 - 2025-02-26 - Changelog","doc":"Initial release. :rocket:","ref":"changelog.html#0-1-0-2025-02-26"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2024 Sasha Gerrand\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}